@@ -67,9 +67,9 @@ function(
   } else {
     filled_constraints_in_x <- sapply(1:ncol(x), function(i_col) {
       is_each_constraint_for_this_col <- sapply(constraints, function(this_cons) {
-        return( this_cons[[1]] == i_col | any((names(x) == this_cons[[1]]) == i_col) )
+        #return( this_cons[[1]] == i_col | any((names(x) == this_cons[[1]]) == i_col) )
+        return( this_cons[[1]] == i_col | names(x)[i_col] == this_cons[[1]] )
       })
-      
       if( 0 == sum(is_each_constraint_for_this_col) ) {
         return( list() )
       } else if( 1 == sum(is_each_constraint_for_this_col) ) {
